
#ifndef I2C_H
#define I2C_H

#include <stdint.h>

/*********************************************************
		Defines
*********************************************************/

#define ARRAY_SIZE(_x) (sizeof(_x)/sizeof(_x[0]))


#define SPI_CLK		0x01
#define SPI_SEL		0x02
#define SPI_MISO	0x04
#define SPI_MOSI	0x08

#define SPI_MASK	(SPI_CLK | SPI_SEL | SPI_MISO | SPI_MOSI)

#define I2C_SDA		0x02
#define I2C_SCL		0x01
#define I2C_MASK (I2C_SDA|I2C_SCL)

typedef enum EI2CState
{
	I2C_IDLE=0,
	I2C_START,
	I2C_DATA,
	I2C_ACK,
	I2C_STOP,
} EI2CState;

/*********************************************************
		TLA Types
*********************************************************/


enum TLA_INFO {
        TLA_INFO_FIRST_SEQUENCE,
        TLA_INFO_LAST_SEQUENCE,
        TLA_INFO_DISPLAY_ATTRIBUTE,
        TLA_INFO_3,
        TLA_INFO_MNEMONICS_WIDTH=5
};

struct lactx;
struct businfo {
	int val0;
	int val4;
	int val8;
	int valc;
	int val10;
	int val14;
	void *val18;
	int val1c;
};

struct modeinfo {
	const char *name;
	const char **options;
	int val1;
	int val2;
};

struct sequence {
	struct sequence *next;
	char *textp;
	uint8_t flags;		//The flags determine the background
										//bit 0= white (blank),  bit 1=grey,  bit 2=red, bit3=yellow
        char field_9;
        char field_A;
        char field_B;
	char *text2;
	int field_10;
	int field_14;
	int field_18;
	int field_1C;
	char text[128];
	char text2_buf[8];
};

struct pctx_functable {
	int (*LAGroupValue)(struct lactx *lactx, int seqno, int group);
	void (*rda_free)(void *p);
        void *(*rda_calloc)(int memb, int size);
        int (*LAInfo)(struct lactx *, enum TLA_INFO, int16_t bus);
};
struct pctx {
	struct lactx *lactx;
	struct pctx_functable func;
};

struct groupinfo {
	char *name;
	char field_4;
	char field_5;
	char field_6;
	char field_7;
	uint16_t members;
	uint16_t len;
};

enum MODEINFO {
	MODEINFO_MAX_BUS=0,
	MODEINFO_MAX_GROUP=1,
	MODEINFO_MAX_MODE=2,
	MODEINFO_3=3,
	MODEINFO_GETNAME=4,
	MODEINFO_MAX,
};

struct lafunc {
	int unknown;	/* field_0 */
	char *support_path;		/* field_4 */
	char *support_sep;  /* field_8 */
	char *support_name;	/* field_C */
	char *support_name2;	/* field_10 */
	char *support_ext; /* field_14 */
	void *(*rda_malloc)(int size); /* field_18 */
	void *(*rda_calloc)(int members, int size); /* field_1C */
	void *(*rda_realloc)(void *p, int size); /* field_20 */
	void (*rda_free)(void *p); /* field_24 */
	void (*LABus)(void);				/* 28 */
	int  (*LAInfo)(struct lactx *, enum TLA_INFO, int16_t bus);			/* 2C */
	void (*LAError)(struct lactx *, int, char *, ...);				/* 30 */
	void (*LAFindSeq)(void);			/* 34 */
	void (*LAFormatValue)(void);		/* 38 */
	void (*LAGap)(void);				/* 3c */
	int (*LAGroupValue)(struct lactx *lactx, int seqno, int group);			/* 40 */
	void (*LAInvalidate)(void);			/* 44 */
	void (*LASeqToText)(void);			/* 48 */
	void (*LAGroupWidth_)(void);		/* 4c */
	void (*LATimeStamp_ps_)(void);		/* 50 */
	void (*LASysTrigTime_ps_)(void);	/* 54 */
	void (*LABusModTrigTime_ps_)(void);	/* 58 */
	void (*LABusModTimeOffset_ps_)(void);	/* 5c */
	void (*LAGroupInvalidBitMask_)(void);	/* 60 */
	void (*LAContigLongToSeq_)(void);		/* 64 */
	void (*LALongToSeq_)(void);				/* 68 */
	void (*LALongToValidSeq_)(void);		/* 6c */
	void (*LASeqToContigLong_)(void);		/* 70 */
	void (*LASeqToLong_)(void);				/* 74 */
	void (*LASubDisasmLoad)(void);			/* 78 */
	void (*LASubDisasmUnload)(void);		/* 7c */
	void (*LASubDisasmFuncTablePtr_)(void);	/* 80 */
	void (*LAWhichBusMod_)(void);			/* 84 */
	void (*LASeqDisplayFormat_)(void);		/* 88 */
	void (*LAInteractiveUI2_)(void);		/* 8c */
	void (*LAProgAbort_)(void);				/* 90 */
	void (*LATimestamp_ps_ToText)(void);	/* 94 */
	void (*LATimeStampDisplayFormat)(void);	/* 98 */
	void (*LAReferenceTime_ps_)(void);		/* 9c */
	void (*LABusModSysTrigTime_ps_)(void);	/* a0 */
	void (*LABusModFrameOffset_ps_)(void);	/* a4 */
	void (*LABusModTimeToUserAlignedTime_ps_)(void); /* a8 */
	void (*LABusModTrigSample)(void);		/* ac */
	void (*LABusModWallClockStart_)(void);	/* b0 */
	void *field_B4;							/* b4 */
	void (*LAReferenceTime_ps_2)(void);		/* b8 */
	void (*LASampleStatusBits)(void);		/* bc */
	void (*LASampleStatusBitsType_)(void);
	void (*LAGroupViolationBitMask_)(void);
	void (*LAGroupViolationBitMaskType_)(void);
	void (*LABusModVariantName_)(void);
	void (*LASystemName_)(void);
	void (*LASystemPath_)(void);
	void *field_DC;
};


/*********************************************************
		SPI Types
*********************************************************/

typedef struct TI2CData
{
	int sequence;	//where this data was found
	int last_sequence;	//where the data ends
	int bit_count;	//where are we?
	uint32_t	i2c_data;		//I2C data

} TI2CData;


typedef struct TSeqData
{
	int seq_number;
	struct sequence seq_data;
} TSignalGenerator;


typedef vector <TSeqData> TVSeqData;



/*********************************************************
		DLL prototypes
*********************************************************/
extern "C"
	{
__declspec(dllexport) struct pctx *ParseReinit(struct pctx *pctx, struct lactx *lactx, struct lafunc *func);
__declspec(dllexport) int ParseFinish(struct pctx *pctx);
__declspec(dllexport) int ParseInfo(struct pctx *pctx, unsigned int request);
__declspec(dllexport) int ParseMarkMenu(struct pctx *, int, int, int, int);
__declspec(dllexport) int ParseMarkGet(struct pctx *pctx, int seq);
__declspec(dllexport) int ParseMarkSet(struct pctx *pctx, int seq, int);
__declspec(dllexport) int ParseMarkNext(struct pctx *pctx, int seq, int);
__declspec(dllexport) int ParseModeGetPut(struct pctx *pctx, int mode, int, int request);
__declspec(dllexport) struct sequence *ParseSeq(struct pctx *, int seq);
__declspec(dllexport) struct businfo *ParseBusInfo(struct pctx *, uint16_t bus);
__declspec(dllexport) struct modeinfo *ParseModeInfo(struct pctx *pctx, uint16_t mode);
__declspec(dllexport) struct groupinfo *ParseGroupInfo(struct pctx *pctx, uint16_t group);
__declspec(dllexport) int ParseDisasmReinit(struct pctx *, int request);
	}

#endif
